@@ -1,8 +1,9 @@
 # Calkulate: seawater total alkalinity from titration data
-# Copyright (C) 2019-2020  Matthew P. Humphreys  (GNU GPLv3)
-"""The densities of various solutions."""
+# Copyright (C) 2019--2021  Matthew P. Humphreys  (GNU GPLv3)
+"""Calculate the density of various solutions."""
 
 import numpy as np
+from . import default
 
 
 def seawater_1atm_MP81(temperature=25, salinity=35):
@@ -14,10 +15,10 @@ def seawater_1atm_MP81(temperature=25, salinity=35):
     """
     if np.any(temperature < 0) or np.any(temperature > 40):
         print("Warning: some temperature values fall outside the valid range")
-        print("for the MP81 density equation (0–40 °C).")
+        print("of the MP81 density equation (0–40 °C).")
     if np.any(salinity < 0.5) or np.any(salinity > 43):
         print("Warning: some salinity values fall outside the valid range")
-        print("for the MP81 density equation (0.5–43).")
+        print("of the MP81 density equation (0.5–43).")
     return (
         999.842594
         + 6.793952e-2 * temperature
@@ -39,7 +40,9 @@ def seawater_1atm_MP81(temperature=25, salinity=35):
     ) * 1e-3
 
 
-def HCl_NaCl_25C_DSC07(molinity_HCl=0.1, molinity_NaCl=0.6):
+def HCl_NaCl_25C_DSC07(
+    molinity_HCl=default.molinity_HCl, molinity_NaCl=default.molinity_NaCl
+):
     """Density of a mixture of HCl and NaCl at 25 °C and 1 atm following DSC07."""
     rhow25 = 0.99704  # g / cm**3
     # For convenience:
